#!/usr/bin/python3 -Es
# -*- coding: utf-8 -*-
#
# Copyright (C) 2002-2018 Red Hat, Inc.
#
# Authors:
# Than Ngo <than@redhat.com>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import os.path
import gettext

PROGNAME = 'system-switch-mail'
TITLE = 'MTA Switcher'
SWITCHMAILDIR = '/usr/share/' + PROGNAME + '/'
GLADEFILE = '/usr/share/' + PROGNAME + "/" + 'switchmail.glade'
INFODIALOG = 0
WARNDIALOG = 1
SENDMAIL =  0 
POSTFIX = 1
EXIM = 2
SSMTP = 3
ESMTP = 4
MTA = ['Sendmail', 'Postfix', 'Exim', 'sSMTP', 'ESMTP']
MTA_PATH = '/etc/alternatives/mta'

#
# I18N
#
gettext.textdomain(PROGNAME)
_ = gettext.gettext

WARNING_TEXT = _('Mail Transport Agent is not installed on system. Please install it and restart this tool again.')
INFO_TEXT = _('Your MTA configuration has succesfully been updated.')
TEXT = _('The Mail Transport Agent Switcher is a tool which enables users to easily switch between various Mail Transport Agent that they have installed. Please choose your Mail transport agent.')

def stop_service(mta):
    os.system('/bin/systemctl stop ' + mta)
    os.system('/bin/systemctl disable ' + mta)

def start_service(mta):
    os.system('/bin/systemctl start ' + mta)
    os.system('/bin/systemctl enable ' + mta)

def alternate(mta):
    os.system('/usr/sbin/alternatives --set mta ' + mta)

def switch(i):
    if i == SENDMAIL:
        alternate('/usr/sbin/sendmail.sendmail')
        stop_service('postfix.service')
        stop_service('exim.service')
        start_service('sendmail.service')
    elif i == POSTFIX:
        alternate('/usr/sbin/sendmail.postfix')
        stop_service('sendmail.service')
        stop_service('exim.service')
        start_service('postfix.service')
    elif i == EXIM:
        alternate('/usr/sbin/sendmail.exim')
        stop_service('postfix.service')
        stop_service('sendmail.service')
        start_service('exim.service')
    elif i == SSMTP:
        alternate('/usr/sbin/sendmail.ssmtp')
        stop_service('sendmail.service')
        stop_service('postfix.service')
        stop_service('exim.service')
    elif i == ESMTP:
        alternate('/usr/bin/esmtp')
        stop_service('sendmail.service')
        stop_service('postfix.service')
        stop_service('exim.service')

def get_mta():
    mta_list = []
    for mta in MTA:
        if os.system('/bin/rpm -q ' + str.lower(mta) + '>/dev/null 2>&1') == 0:
            mta_list.append(mta)

    return(mta_list)

def get_default_mta(mta_list):
    if os.path.exists(MTA_PATH) and os.path.islink(MTA_PATH):
        default_mta = os.readlink(MTA_PATH)
        if default_mta == '/usr/sbin/sendmail.sendmail':
            return MTA[SENDMAIL]
        elif default_mta == '/usr/sbin/sendmail.postfix':
            return MTA[POSTFIX]
        elif default_mta == '/usr/sbin/sendmail.exim':
            return MTA[EXIM]
        elif default_mta == '/usr/sbin/sendmail.ssmtp':
            return MTA[SSMTP]
        elif default_mta == '/usr/bin/esmtp':
            return MTA[ESMTP]

    return mta_list[SENDMAIL]
